pub struct ManualTimeProvider { /* private fields */ }Expand description
Implementation of TimeProvider that allows manual control of time
This provider allows you to explicitly set the current time for testing time-dependent code without relying on the system clock.
Implementations
Sourceimpl ManualTimeProvider
impl ManualTimeProvider
Sourcepub fn new(start_time_millis: TimeMillis) -> Self
pub fn new(start_time_millis: TimeMillis) -> Self
Create a new ManualTimeProvider with a specified starting time
Sourcepub async fn run_all_sleepers_till_done(
&self,
cancellation_token: &CancellationToken,
)
pub async fn run_all_sleepers_till_done( &self, cancellation_token: &CancellationToken, )
Advance time until there are no more registered sleepers.
It jumps time forward to the next wakeup repeatedly, waking all due tasks, and yields to the executor so those tasks can make progress and potentially register more sleeps.
Sourcepub async fn advance_time_until_next_sleeper(&self)
pub async fn advance_time_until_next_sleeper(&self)
Advance time to the earlier of: the next scheduled wake time or the current time plus max_advance_ms
Returns the amount of time (in milliseconds) that was actually advanced and the remaining number of sleeping taks